/*
 * bootstrap-sphinx.css
 * ~~~~~~~~~~~~~~~~~~~~
 *
 * Sphinx stylesheet -- Bootstrap theme.
 */


/* The code below is based on the bootstrap website sidebar */


/* Show and affix the side nav when space allows it */
@media screen and (min-width: 992px) {
  .bs-sidenav .nav > .active > ul {
    display: block;
  }
  div.bs-sidenav ul {
    margin-bottom: 0;
    padding-left: 5px;
    list-style: none;
  }
  div.bs-sidenav a {
    color: #333333;
  }
  /* Widen the fixed sidenav */
  .bs-sidenav.affix,
  .bs-sidenav.affix-bottom {
    width: 292px;
  }
  .bs-sidenav.affix {
    position: fixed; /* Undo the static from mobile first approach */
  }
  .bs-sidenav.affix-bottom {
    position: absolute; /* Undo the static from mobile first approach */
  }
  .bs-sidenav.affix-bottom .bs-sidenav,
  .bs-sidenav.affix .bs-sidenav {
    margin-top: 0;
    margin-bottom: 0;
  }
}
@media screen and (min-width: 1200px) {
  /* Widen the fixed sidenav again */
  .bs-sidenav.affix-bottom,
  .bs-sidenav.affix {
    width: 360px;
  }
}
